CaptureNetworkTrafficCommand.Entry (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.commands
Class CaptureNetworkTrafficCommand.Entry

    java.lang.Object
      org.openqa.selenium.server.commands.CaptureNetworkTrafficCommand.Entry

Enclosing class:
  CaptureNetworkTrafficCommand

    public static class CaptureNetworkTrafficCommand.Entry

extends java.lang.Object

Constructor Summary
`CaptureNetworkTrafficCommand.Entry(java.lang.String method, java.lang.String url)`

Method Summary
`void` | `addRequestHeader(java.lang.String key, java.lang.String value)`
`void` | `addRequestHeaders(org.mortbay.http.HttpRequest request)`
`void` | `addResponseHeader(org.mortbay.http.HttpResponse response)`
`void` | `finish(int statusCode, long bytes)`
`void` | `setEnd(java.util.Date end)`
`void` | `setStart(java.util.Date start)`
`java.lang.String` | `toString()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait`

Constructor Detail

### CaptureNetworkTrafficCommand.Entry

    public CaptureNetworkTrafficCommand.Entry(java.lang.String method,
                                              java.lang.String url)

Method Detail

### finish

    public void finish(int statusCode,
                       long bytes)

### addRequestHeaders

    public void addRequestHeaders(org.mortbay.http.HttpRequest request)

### addResponseHeader

    public void addResponseHeader(org.mortbay.http.HttpResponse response)

### setStart

    public void setStart(java.util.Date start)

### setEnd

    public void setEnd(java.util.Date end)

### toString

    public java.lang.String toString()

  Overrides:
    `toString` in class `java.lang.Object`

### addRequestHeader

    public void addRequestHeader(java.lang.String key,
                                 java.lang.String value)

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.